/*
 *    Plugin configure dialog.
 */
#include <audacious/plugin.h>

void vtx_config(void)
{


}
